#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-3QWbzRv7q5rA4SexVuE0uq
key:                  hasql-transaction-1.0.1.1-3QWbzRv7q5rA4SexVuE0uq
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  12ac6d19b3f1e85d44e6b2df959868ec
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-3QWbzRv7q5rA4SexVuE0uq
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-M0Zq1lQWSk3D1cC9tvexJ
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    contravariant-extras-0.3.5.4-3woyg6AJRP6Lk666ZeP5zR
    hasql-1.5.0.5-8L7Nt9yqgHTDZA25jae2rY mtl-2.3.1 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

